==> htscanner-0.5.0.tgz: htscanner-0.5.0/php_htscanner.h <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2004 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.0 of the PHP license,       |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_0.txt.                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author:		Bart Vanbrabant <bart dot vanbrabant at zoeloelip dot be>|
  +----------------------------------------------------------------------+
*/

/* $Id: php_htscanner.h,v 1.1 2006/11/30 01:54:09 pajoye Exp $ */

#ifndef PHP_HTSCANNER_H
#define PHP_HTSCANNER_H

extern zend_module_entry htscanner_module_entry;
#define phpext_htscanner_ptr &htscanner_module_entry

#ifdef PHP_WIN32
#define PHP_HTSCANNER_API __declspec(dllexport)
#else
#define PHP_HTSCANNER_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

#define HTSCANNER_VERSION "0.4"

PHP_MINIT_FUNCTION(htscanner);
PHP_MSHUTDOWN_FUNCTION(htscanner);
PHP_RINIT_FUNCTION(htscanner);
PHP_RSHUTDOWN_FUNCTION(htscanner);
PHP_MINFO_FUNCTION(htscanner);

ZEND_BEGIN_MODULE_GLOBALS(htscanner)
	char *config_file;
	char *default_docroot;
ZEND_END_MODULE_GLOBALS(htscanner)

#ifdef ZTS
#define HTG(v) TSRMG(htscanner_globals_id, zend_htscanner_globals *, v)
#else
#define HTG(v) (htscanner_globals.v)
#endif

#endif	/* PHP_HTSCANNER_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> htscanner-0.6.1.tgz: htscanner-0.6.1/php_htscanner.h <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2004 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.0 of the PHP license,       |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_0.txt.                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author:		Bart Vanbrabant <bart dot vanbrabant at zoeloelip dot be>|
  +----------------------------------------------------------------------+
*/

/* $Id: php_htscanner.h,v 1.2 2006/12/07 19:41:10 pajoye Exp $ */

#ifndef PHP_HTSCANNER_H
#define PHP_HTSCANNER_H

extern zend_module_entry htscanner_module_entry;
#define phpext_htscanner_ptr &htscanner_module_entry

#ifdef PHP_WIN32
#define PHP_HTSCANNER_API __declspec(dllexport)
#else
#define PHP_HTSCANNER_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

#define HTSCANNER_VERSION "0.6.0"

PHP_MINIT_FUNCTION(htscanner);
PHP_MSHUTDOWN_FUNCTION(htscanner);
PHP_RINIT_FUNCTION(htscanner);
PHP_RSHUTDOWN_FUNCTION(htscanner);
PHP_MINFO_FUNCTION(htscanner);

typedef struct _ze_htscanner_cache_entry {
	time_t created_on;
	HashTable *ini_entries;
} htscanner_cache_entry;

typedef struct _ze_htscanner_cache {
	HashTable *paths;
} htscanner_cache;

ZEND_BEGIN_MODULE_GLOBALS(htscanner)
	char *config_file;
	char *default_docroot;
	unsigned long default_ttl;
ZEND_END_MODULE_GLOBALS(htscanner)

#ifdef ZTS
#define HTG(v) TSRMG(htscanner_globals_id, zend_htscanner_globals *, v)
#define htscannerMutexDeclare(x) MUTEX_T x
#define htscannerMutexSetup(x) x = tsrm_mutex_alloc()
#define htscannerMutexShutdown(x) tsrm_mutex_free(x)
#define htscannerMutexLock(x) tsrm_mutex_lock(x)
#define htscannerUnlock(x) tsrm_mutex_unlock(x)
#else
#define HTG(v) (htscanner_globals.v)
#define htscannerMutexDeclare(x)
#define htscannerMutexSetup(x)
#define htscannerMutexShutdown(x)
#define htscannerMutexLock(x)
#define htscannerMutexUnlock(x)
#endif

#endif	/* PHP_HTSCANNER_H */
/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
